# falco-app

[![PyPI - Version](https://img.shields.io/pypi/v/falco-app.svg)](https://pypi.org/project/falco-app)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/falco-app.svg)](https://pypi.org/project/falco-app)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install falco-app
```

## License

`falco-app` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
